package com.qmth.boot.core.solar.crypto;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.qmth.boot.core.solar.model.AppLicense;
import com.qmth.boot.tools.codec.CodecUtils;
import com.qmth.boot.tools.crypto.RSA;
import com.qmth.boot.tools.models.ByteArray;
import org.apache.commons.lang3.ArrayUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.File;
import java.util.Arrays;

/**
 * 应用许可证解析工具
 */
public class AppLicenseParser {

    private static final Logger log = LoggerFactory.getLogger(AppLicenseParser.class);

    private static final String PUBLIC_KEY_PATH = "license/public.key";

    /**
     * 通过许可证文件路径尝试解析
     *
     * @param filePath
     * @return
     */
    public static AppLicense parse(String filePath) {
        try {
            byte[] original = ByteArray.fromFile(new File(filePath)).value();
            byte[] digest = ArrayUtils.subarray(original, 0, 16);
            byte[] content = RSA.getPublicKey(ByteArray
                    .fromInputStream(AppLicenseParser.class.getClassLoader().getResourceAsStream(PUBLIC_KEY_PATH))
                    .value()).decrypt(ArrayUtils.subarray(original, 16, original.length)).value();
            if (Arrays.equals(digest, CodecUtils.md5(content))) {
                return new ObjectMapper().readValue(content, AppLicense.class);
            }
        } catch (Exception e) {
            log.error("Solar license parse error", e);
        }
        return null;
    }

}
